# Motor

OpenMV tiene puertos IO y puede accionar varios motores.

## motor paso a paso

### ¿Qué es un motor paso a paso

El motor paso a paso es un motor de control de bucle abierto que convierte
señales de impulsos eléctricos en desplazamiento angular o desplazamiento
lineal. Es el elemento ejecutivo principal en los sistemas de control de
programas digitales modernos y se usa ampliamente.

Como impresoras 3D y brazos robóticos.

### Placa controladora de motor paso a paso

Muchos chips y módulos pueden controlar motores paso a paso. Usamos un módulo
muy simple, EasyDriver.

En pocas palabras, la dirección está controlada por dir. Si se le da un pulso al
paso, el motor se moverá un paso.

![](/assets/06-07-001.jpg)

### Conectar

![](/assets/06-07-002.jpg)

## Instalar módulo

[El código del módulo está en este
enlace](http://book.openmv.cc/module/write-module-motor.html)

Guarde el código de esta clase como un archivo stepper.py y colóquelo en el
directorio raíz de OpenMV.

## código

```python
# 步进电机控制 - By: 小智智- 周日 4月 2 2017

from pyb import Pin

from stepper import Stepper

import time

step_pin = Pin('P0')
dir_pin = Pin('P1')

my_stepper = Stepper(step_pin,dir_pin)

print("relative angle move test begin:", my_stepper.read_pos())
my_stepper.rel_angle(180)#相对角度控制
print("relative angle move test end:", my_stepper.read_pos())

time.sleep_ms(1000)

print("steps angle move test end:", my_stepper.read_pos())
my_stepper.steps(-400)#步进脉冲控制
print("steps angle move test end:", my_stepper.read_pos())

time.sleep_ms(1000)

print("absolute angle move test begin:", my_stepper.read_pos())
my_stepper.abs_angle(0)#绝对角度控制
print("absolute angle move test end:", my_stepper.read_pos())

time.sleep_ms(1000)
```

## motor de corriente continua

#### Tutorial 26: La versión de extensión del motor controla el motor de CC: [https://singtown.com/video](https://singtown.com/video)

### ¿Qué es un motor de CC?

La velocidad de un motor de CC es directamente proporcional al voltaje.

### tablero de conductor

Muchas placas de controlador pueden accionar motores de CC; aquí usamos
TB6612FNG, puente H dual.

![](/assets/06-07-003.jpg)

### Conectar

![](/assets/06-07-004.jpg)

### código

```python
待添加
```

## mecanismo de dirección

OpenMV2 tiene dos pines de servo, P7 y P8

OpenMV3 tiene tres pines de servo, P7, P8, P9

### Conectar

![](/assets/06-07-005.jpg)

### Compruebe la fuente de alimentación

El servo es un dispositivo de alta corriente y debe utilizar una fuente de
alimentación externa (fuente de alimentación regulada, batería de litio... ¡el
USB no puede alimentar el servo!

### código

```python
# Servo Control Example
#
# This example shows how to use your OpenMV Cam to control servos.

import time
from pyb import Servo

s1 = Servo(1) # P7
s2 = Servo(2) # P8
#s3 = Servo(3) # P9 Only for OpenMV3 M7
while(True):
    for i in range(-90,90):
        s1.angle(i)
        s2.angle(i)
        time.sleep_ms(10)
    for i in range(90,-90):
        s1.angle(i)
        s2.angle(i)
        time.sleep_ms(10)
```

## PCA9685 conecta múltiples servos

Enlace para bebés:
[https://singtown.com/product/49277](https://singtown.com/product/49277)

#### Vídeo tutorial 25 - pca9685 controla varios servos: [https://singtown.com/learn/50057/](https://singtown.com/learn/50057/)



El módulo PCA9685, que utiliza solo 2 pines (protocolo I2C), puede controlar 16
canales PWM, que son 16 servos o 16 luces LED. ¡Incluso puedes conectar 62
módulos y seguir usando solo 2 pines para controlar 992 PWM!

Conectar

![](/assets/06-07-006-01.jpg)

código

![](/assets/06-07-007.jpg)

Haga clic para ejecutar

